@@ -54,7 +54,12 @@ gravity <- function(travel_matrix,
   assert_decay_function(decay_function)
   assert_group_by(group_by)
   assert_travel_matrix(travel_matrix, travel_cost, group_by)
-  assert_land_use_data(land_use_data, opportunity)
+  assert_land_use_data(
+    land_use_data,
+    travel_matrix,
+    opportunity,
+    active = active
+  )
 
   # if not a dt, keep original class to assign later when returning result
 
